@@ -36,7 +36,9 @@
 #include <unistd.h>
 
 char remote_input_buf[PATH_MAX + 5];
+#ifdef HAVE_ALSA
 extern long volume_max;
+#endif
 
 static
 enum mad_flow remote_parse_input(buffer *buf, playlist *pl)
@@ -193,18 +195,30 @@ enum mad_flow remote_parse_input(buffer *buf, playlist *pl)
     {
        if (arg)
        {
+#ifdef HAVE_ALSA
 	       if(options.opt & MPG321_ENABLE_BUFFER)
-		       mpg321_alsa_set_volume((long)atol(arg)*volume_max/100.0);
-	       else
-	    	       options.volume = mad_f_tofixed(atoi(arg)/100.0);
+		       mpg321_alsa_set_volume((long)atol(arg)*volume_max/100);
+	       else{
+#endif
+		       if(!(options.opt & MPG321_ENABLE_BUFFER))
+		    	       options.volume = mad_f_tofixed(atoi(arg)/100.0);
+#ifdef HAVE_ALSA
+	       }
+#endif
            free(arg);
        }
        else
        {
+#ifdef HAVE_ALSA
 	       if(options.opt & MPG321_ENABLE_BUFFER)
 	           fprintf(stderr, "@G %lu\n", (int)(100*mpg321_alsa_get_volume()/volume_max));
-	       else
-	           fprintf(stderr, "@G %d\n", (int)((double)options.volume / (1 << MAD_F_FRACBITS) * 100.0));
+	       else{
+#endif
+		       if(!(options.opt & MPG321_ENABLE_BUFFER))
+		           fprintf(stderr, "@G %d\n", (int)((double)options.volume / (1 << MAD_F_FRACBITS) * 100.0));
+#ifdef HAVE_ALSA
+	       }
+#endif
        }
 
        return MAD_FLOW_CONTINUE;
